@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,12 +8,12 @@
 #include "autocreatescripts/commonwidgets/selectconvertparameterwidget.h"
 #include "autocreatescripts/commonwidgets/selectmimetypecombobox.h"
 
-#include <KLocalizedString>
-
-#include <QLabel>
 #include "libksieve_debug.h"
-#include <QXmlStreamReader>
+#include <KLocalizedString>
 #include <QGridLayout>
+#include <QLabel>
+#include <QUrl>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 SieveActionConvert::SieveActionConvert(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
@@ -23,15 +23,15 @@ SieveActionConvert::SieveActionConvert(SieveEditorGraphicalModeWidget *sieveGrap
 
 QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QGridLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QGridLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    QLabel *lab = new QLabel(i18n("From:"));
+    auto lab = new QLabel(i18n("From:"));
     lay->addWidget(lab, 0, 0);
 
-    auto *fromMimeType = new SelectMimeTypeComboBox;
+    auto fromMimeType = new SelectMimeTypeComboBox;
     connect(fromMimeType, &SelectMimeTypeComboBox::valueChanged, this, &SieveActionConvert::valueChanged);
     fromMimeType->setObjectName(QStringLiteral("from"));
     lay->addWidget(fromMimeType, 0, 1);
@@ -39,7 +39,7 @@ QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("To:"));
     lay->addWidget(lab, 0, 2);
 
-    auto *toMimeType = new SelectMimeTypeComboBox;
+    auto toMimeType = new SelectMimeTypeComboBox;
     connect(toMimeType, &SelectMimeTypeComboBox::valueChanged, this, &SieveActionConvert::valueChanged);
     toMimeType->setObjectName(QStringLiteral("to"));
     lay->addWidget(toMimeType, 0, 3);
@@ -47,7 +47,7 @@ QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Parameters:"));
     lay->addWidget(lab, 1, 0);
 
-    auto *params = new SelectConvertParameterWidget;
+    auto params = new SelectConvertParameterWidget;
     connect(params, &SelectConvertParameterWidget::valueChanged, this, &SieveActionConvert::valueChanged);
     params->setObjectName(QStringLiteral("params"));
     lay->addWidget(params, 1, 1, 2, 3);
@@ -62,10 +62,10 @@ void SieveActionConvert::setParamWidgetValue(QXmlStreamReader &element, QWidget
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("str")) {
             if (index == 0) {
-                auto *fromMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("from"));
+                auto fromMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("from"));
                 fromMimeType->setCode(element.readElementText(), name(), error);
             } else if (index == 1) {
-                auto *toMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("to"));
+                auto toMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("to"));
                 toMimeType->setCode(element.readElementText(), name(), error);
             } else {
                 tooManyArguments(tagName, index, 2, error);
@@ -73,14 +73,14 @@ void SieveActionConvert::setParamWidgetValue(QXmlStreamReader &element, QWidget
             }
             ++index;
         } else if (tagName == QLatin1String("list")) {
-            auto *params = w->findChild<SelectConvertParameterWidget *>(QStringLiteral("params"));
+            auto params = w->findChild<SelectConvertParameterWidget *>(QStringLiteral("params"));
             params->setCode(AutoCreateScriptUtil::listValue(element), error);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << "SieveActionConvert::setParamWidgetValue unknown tag " << tagName;
@@ -125,7 +125,9 @@ QString SieveActionConvert::serverNeedsCapability() const
 
 QString SieveActionConvert::help() const
 {
-    return i18n("The \"convert\" action specifies that all body parts with a media type equal to \"media-type\" be converted to the media type in \"media-type\" using conversion parameters.");
+    return i18n(
+        "The \"convert\" action specifies that all body parts with a media type equal to \"media-type\" be converted to the media type in \"media-type\" using "
+        "conversion parameters.");
 }
 
 QUrl SieveActionConvert::href() const
