@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -64,7 +64,7 @@ void SieveEditorTabWidget::slotTabContextMenuRequest(const QPoint &pos)
     QAction *action = menu.exec(mapToGlobal(pos));
 
     if (action) {
-        if (action == allOther) {   // Close all other tabs
+        if (action == allOther) { // Close all other tabs
             slotCloseAllTabExcept(indexBar);
         } else if (action == closeTab) {
             slotCloseRequest(indexBar);
@@ -83,7 +83,7 @@ void SieveEditorTabWidget::slotCloseRequest(int index)
 
 void SieveEditorTabWidget::closeAllTabExcept(int index)
 {
-    //Don't close first tab
+    // Don't close first tab
     for (int i = count() - 1; i > 0; --i) {
         if (i == index) {
             continue;
@@ -104,7 +104,7 @@ void SieveEditorTabWidget::slotCloseAllTab()
 
 void SieveEditorTabWidget::slotTabCloseRequested(int index)
 {
-    //Don't remove first tab.
+    // Don't remove first tab.
     if (index > 0) {
         removeTab(index);
     }
@@ -112,13 +112,13 @@ void SieveEditorTabWidget::slotTabCloseRequested(int index)
 
 bool SieveEditorTabWidget::currentPageIsHtmlPage() const
 {
-    auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
     return page ? true : false;
 }
 
 QUrl SieveEditorTabWidget::currentHelpUrl() const
 {
-    auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
     if (page) {
         return page->currentUrl();
     }
@@ -127,7 +127,7 @@ QUrl SieveEditorTabWidget::currentHelpUrl() const
 
 QString SieveEditorTabWidget::currentHelpTitle() const
 {
-    auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
+    auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(currentWidget());
     if (page) {
         return page->title();
     }
@@ -137,13 +137,13 @@ QString SieveEditorTabWidget::currentHelpTitle() const
 void SieveEditorTabWidget::slotAddHelpPage(const QUrl &url)
 {
     for (int i = 0; i < count(); ++i) {
-        auto *page = qobject_cast<SieveEditorHelpHtmlWidget *>(widget(i));
+        auto page = qobject_cast<SieveEditorHelpHtmlWidget *>(widget(i));
         if (page && page->currentUrl() == url) {
             setCurrentIndex(i);
             return;
         }
     }
-    auto *htmlPage = new SieveEditorHelpHtmlWidget;
+    auto htmlPage = new SieveEditorHelpHtmlWidget;
     connect(htmlPage, &SieveEditorHelpHtmlWidget::titleChanged, this, &SieveEditorTabWidget::slotTitleChanged);
     connect(htmlPage, &SieveEditorHelpHtmlWidget::progressIndicatorPixmapChanged, this, &SieveEditorTabWidget::slotProgressIndicatorPixmapChanged);
     connect(htmlPage, &SieveEditorHelpHtmlWidget::loadFinished, this, &SieveEditorTabWidget::slotLoadFinished);
